==> haskell-x509-1.7.7-158.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-x509.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 x509
version:              1.7.7
visibility:           public
id:                   x509-1.7.7-G6zPGK1ibFfIt8zpQB2m8y
key:                  x509-1.7.7-G6zPGK1ibFfIt8zpQB2m8y
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-certificate
synopsis:             X509 reader and writer
description:          X509 reader and writer. please see README
category:             Data
abi:                  8ba58f6df5b60d34bcaed9d8440368b7
exposed:              True
exposed-modules:      Data.X509 Data.X509.EC
hidden-modules:
    Data.X509.Internal Data.X509.CertificateChain
    Data.X509.AlgorithmIdentifier Data.X509.DistinguishedName
    Data.X509.Cert Data.X509.PublicKey Data.X509.PrivateKey
    Data.X509.Ext Data.X509.ExtensionRaw Data.X509.CRL Data.X509.OID
    Data.X509.Signed

import-dirs:          /usr/lib/ghc-9.6.6/site-local/x509-1.7.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/x509-1.7.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/x509-1.7.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-x509
hs-libraries:         HSx509-1.7.7-G6zPGK1ibFfIt8zpQB2m8y
depends:
    asn1-encoding-0.9.6-f2brNU34Hf3xe9CSPQRHn
    asn1-parse-0.9.5-Hme4OEszotC4nSFnPS5Zk5
    asn1-types-0.3.4-463kziEGjPc1qXS6uMhRJO base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-LM2EJiGJsV242NzdXbkugt
    hourglass-0.2.12-9RVtelOw0wXG6YiBQxfho6
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    pem-0.2.4-BtvjegbjHoRAGAf9oBrW3C transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-x509/html/x509.haddock
haddock-html:         /usr/share/doc/haskell-x509/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-1.7.7-159-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-x509.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 x509
version:              1.7.7
visibility:           public
id:                   x509-1.7.7-KxMQ7VYXWLLK5KLprt1G1
key:                  x509-1.7.7-KxMQ7VYXWLLK5KLprt1G1
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-certificate
synopsis:             X509 reader and writer
description:          X509 reader and writer. please see README
category:             Data
abi:                  d2f3ab82e733a716684e7904371d8df6
exposed:              True
exposed-modules:      Data.X509 Data.X509.EC
hidden-modules:
    Data.X509.Internal Data.X509.CertificateChain
    Data.X509.AlgorithmIdentifier Data.X509.DistinguishedName
    Data.X509.Cert Data.X509.PublicKey Data.X509.PrivateKey
    Data.X509.Ext Data.X509.ExtensionRaw Data.X509.CRL Data.X509.OID
    Data.X509.Signed

import-dirs:          /usr/lib/ghc-9.6.6/site-local/x509-1.7.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/x509-1.7.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/x509-1.7.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-x509
hs-libraries:         HSx509-1.7.7-KxMQ7VYXWLLK5KLprt1G1
depends:
    asn1-encoding-0.9.6-4rkJHO0pUeFCGFdsLyrUdt
    asn1-parse-0.9.5-DinlHyBahm8CwVodLrJ7aO
    asn1-types-0.3.4-3PelmjEeZz36Y9JkroV62e base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-5QYVWJr24zH1Zlsr0wVxCr
    hourglass-0.2.12-91uaLvWJDdFIwz6ObSsY6A
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    pem-0.2.4-G3GIG2bUe0L9P6z0Mw3OGw transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-x509/html/x509.haddock
haddock-html:         /usr/share/doc/haskell-x509/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
